==> libgtop-1.1.4.tar.gz: libgtop-1.1.4/backends/sysdeps/marshal.c <==
/* marshal.c */
/* This is a generated file.  Please modify `marshal.pl' */

#include <glibtop.h>
#include <glibtop/open.h>
#include <glibtop/xmalloc.h>

#include <glibtop/sysdeps.h>
#include <glibtop/union.h>

#include <glibtop/backend.h>

#include <glibtop-backend-private.h>

#if (!GLIBTOP_SUID_CPU)

static int
_glibtop_get_cpu_c (glibtop *server, glibtop_backend *backend, glibtop_cpu *buf)
{
	return glibtop_get_cpu_s (server, buf);

}

#endif /* not GLIBTOP_SUID_CPU */


#if (!GLIBTOP_SUID_MEM)

static int
_glibtop_get_mem_c (glibtop *server, glibtop_backend *backend, glibtop_mem *buf)
{
	return glibtop_get_mem_s (server, buf);

}

#endif /* not GLIBTOP_SUID_MEM */


#if (!GLIBTOP_SUID_SWAP)

static int
_glibtop_get_swap_c (glibtop *server, glibtop_backend *backend, glibtop_swap *buf)
{
	return glibtop_get_swap_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SWAP */


#if (!GLIBTOP_SUID_UPTIME)

static int
_glibtop_get_uptime_c (glibtop *server, glibtop_backend *backend, glibtop_uptime *buf)
{
	return glibtop_get_uptime_s (server, buf);

}

#endif /* not GLIBTOP_SUID_UPTIME */


#if (!GLIBTOP_SUID_LOADAVG)

static int
_glibtop_get_loadavg_c (glibtop *server, glibtop_backend *backend, glibtop_loadavg *buf)
{
	return glibtop_get_loadavg_s (server, buf);

}

#endif /* not GLIBTOP_SUID_LOADAVG */


#if (!GLIBTOP_SUID_SHM_LIMITS)

static int
_glibtop_get_shm_limits_c (glibtop *server, glibtop_backend *backend, glibtop_shm_limits *buf)
{
	return glibtop_get_shm_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SHM_LIMITS */


#if (!GLIBTOP_SUID_MSG_LIMITS)

static int
_glibtop_get_msg_limits_c (glibtop *server, glibtop_backend *backend, glibtop_msg_limits *buf)
{
	return glibtop_get_msg_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_MSG_LIMITS */


#if (!GLIBTOP_SUID_SEM_LIMITS)

static int
_glibtop_get_sem_limits_c (glibtop *server, glibtop_backend *backend, glibtop_sem_limits *buf)
{
	return glibtop_get_sem_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SEM_LIMITS */


#if (!GLIBTOP_SUID_PROCLIST)

static unsigned *
_glibtop_get_proclist_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                         int64_t which, int64_t arg)
{
	return glibtop_get_proclist_s (server, array, which, arg);

}

#endif /* not GLIBTOP_SUID_PROCLIST */


#if (!GLIBTOP_SUID_PROC_STATE)

static int
_glibtop_get_proc_state_c (glibtop *server, glibtop_backend *backend, glibtop_proc_state *buf,
                           pid_t pid)
{
	return glibtop_get_proc_state_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_STATE */


#if (!GLIBTOP_SUID_PROC_UID)

static int
_glibtop_get_proc_uid_c (glibtop *server, glibtop_backend *backend, glibtop_proc_uid *buf,
                         pid_t pid)
{
	return glibtop_get_proc_uid_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_UID */


#if (!GLIBTOP_SUID_PROC_MEM)

static int
_glibtop_get_proc_mem_c (glibtop *server, glibtop_backend *backend, glibtop_proc_mem *buf,
                         pid_t pid)
{
	return glibtop_get_proc_mem_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_MEM */


#if (!GLIBTOP_SUID_PROC_TIME)

static int
_glibtop_get_proc_time_c (glibtop *server, glibtop_backend *backend, glibtop_proc_time *buf,
                          pid_t pid)
{
	return glibtop_get_proc_time_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_TIME */


#if (!GLIBTOP_SUID_PROC_SIGNAL)

static int
_glibtop_get_proc_signal_c (glibtop *server, glibtop_backend *backend, glibtop_proc_signal *buf,
                            pid_t pid)
{
	return glibtop_get_proc_signal_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_SIGNAL */


#if (!GLIBTOP_SUID_PROC_KERNEL)

static int
_glibtop_get_proc_kernel_c (glibtop *server, glibtop_backend *backend, glibtop_proc_kernel *buf,
                            pid_t pid)
{
	return glibtop_get_proc_kernel_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_KERNEL */


#if (!GLIBTOP_SUID_PROC_SEGMENT)

static int
_glibtop_get_proc_segment_c (glibtop *server, glibtop_backend *backend, glibtop_proc_segment *buf,
                             pid_t pid)
{
	return glibtop_get_proc_segment_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_SEGMENT */


#if (!GLIBTOP_SUID_PROC_ARGS)

static char **
_glibtop_get_proc_args_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                          pid_t pid)
{
	return glibtop_get_proc_args_s (server, array, pid);

}

#endif /* not GLIBTOP_SUID_PROC_ARGS */


#if (!GLIBTOP_SUID_PROC_MAP)

static glibtop_map_entry *
_glibtop_get_proc_map_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                         pid_t pid)
{
	return glibtop_get_proc_map_s (server, array, pid);

}

#endif /* not GLIBTOP_SUID_PROC_MAP */


#if (!GLIBTOP_SUID_INTERFACE_NAMES)

static glibtop_interface *
_glibtop_get_interface_names_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                                u_int64_t interface, u_int64_t number, u_int64_t instance, u_int64_t strategy)
{
	return glibtop_get_interface_names_s (server, array, interface, number, instance, strategy);

}

#endif /* not GLIBTOP_SUID_INTERFACE_NAMES */


#if (!GLIBTOP_SUID_NETINFO)

static int
_glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_netinfo *buf,
                        const char * interface, unsigned transport)
{
	return glibtop_get_netinfo_s (server, buf, interface, transport);

}

#endif /* not GLIBTOP_SUID_NETINFO */


#if (!GLIBTOP_SUID_NETLOAD)

static int
_glibtop_get_netload_c (glibtop *server, glibtop_backend *backend, glibtop_netload *buf,
                        const char * interface, unsigned transport, unsigned protocol)
{
	return glibtop_get_netload_s (server, buf, interface, transport, protocol);

}

#endif /* not GLIBTOP_SUID_NETLOAD */


#if (!GLIBTOP_SUID_PPP)

static int
_glibtop_get_ppp_c (glibtop *server, glibtop_backend *backend, glibtop_ppp *buf,
                    unsigned short device)
{
	return glibtop_get_ppp_s (server, buf, device);

}

#endif /* not GLIBTOP_SUID_PPP */


glibtop_call_vector glibtop_backend_sysdeps_call_vector = {
#if GLIBTOP_SUID_CPU
	NULL,
#else
	_glibtop_get_cpu_c,
#endif
#if GLIBTOP_SUID_MEM
	NULL,
#else
	_glibtop_get_mem_c,
#endif
#if GLIBTOP_SUID_SWAP
	NULL,
#else
	_glibtop_get_swap_c,
#endif
#if GLIBTOP_SUID_UPTIME
	NULL,
#else
	_glibtop_get_uptime_c,
#endif
#if GLIBTOP_SUID_LOADAVG
	NULL,
#else
	_glibtop_get_loadavg_c,
#endif
#if GLIBTOP_SUID_SHM_LIMITS
	NULL,
#else
	_glibtop_get_shm_limits_c,
#endif
#if GLIBTOP_SUID_MSG_LIMITS
	NULL,
#else
	_glibtop_get_msg_limits_c,
#endif
#if GLIBTOP_SUID_SEM_LIMITS
	NULL,
#else
	_glibtop_get_sem_limits_c,
#endif
#if GLIBTOP_SUID_PROCLIST
	NULL,
#else
	_glibtop_get_proclist_c,
#endif
#if GLIBTOP_SUID_PROC_STATE
	NULL,
#else
	_glibtop_get_proc_state_c,
#endif
#if GLIBTOP_SUID_PROC_UID
	NULL,
#else
	_glibtop_get_proc_uid_c,
#endif
#if GLIBTOP_SUID_PROC_MEM
	NULL,
#else
	_glibtop_get_proc_mem_c,
#endif
#if GLIBTOP_SUID_PROC_TIME
	NULL,
#else
	_glibtop_get_proc_time_c,
#endif
#if GLIBTOP_SUID_PROC_SIGNAL
	NULL,
#else
	_glibtop_get_proc_signal_c,
#endif
#if GLIBTOP_SUID_PROC_KERNEL
	NULL,
#else
	_glibtop_get_proc_kernel_c,
#endif
#if GLIBTOP_SUID_PROC_SEGMENT
	NULL,
#else
	_glibtop_get_proc_segment_c,
#endif
#if GLIBTOP_SUID_PROC_ARGS
	NULL,
#else
	_glibtop_get_proc_args_c,
#endif
#if GLIBTOP_SUID_PROC_MAP
	NULL,
#else
	_glibtop_get_proc_map_c,
#endif
	NULL,
	NULL,
#if GLIBTOP_SUID_INTERFACE_NAMES
	NULL,
#else
	_glibtop_get_interface_names_c,
#endif
#if GLIBTOP_SUID_NETINFO
	NULL,
#else
	_glibtop_get_netinfo_c,
#endif
#if GLIBTOP_SUID_NETLOAD
	NULL,
#else
	_glibtop_get_netload_c,
#endif
#if GLIBTOP_SUID_PPP
	NULL,
#else
	_glibtop_get_ppp_c,
#endif
};

glibtop_init_func_t _glibtop_init_hook_s [] = {
#if !GLIBTOP_SUID_CPU
	glibtop_init_cpu_s,
#endif
#if !GLIBTOP_SUID_MEM
	glibtop_init_mem_s,
#endif
#if !GLIBTOP_SUID_SWAP
	glibtop_init_swap_s,
#endif
#if !GLIBTOP_SUID_UPTIME
	glibtop_init_uptime_s,
#endif
#if !GLIBTOP_SUID_LOADAVG
	glibtop_init_loadavg_s,
#endif
#if !GLIBTOP_SUID_SHM_LIMITS
	glibtop_init_shm_limits_s,
#endif
#if !GLIBTOP_SUID_MSG_LIMITS
	glibtop_init_msg_limits_s,
#endif
#if !GLIBTOP_SUID_SEM_LIMITS
	glibtop_init_sem_limits_s,
#endif
#if !GLIBTOP_SUID_PROCLIST
	glibtop_init_proclist_s,
#endif
#if !GLIBTOP_SUID_PROC_STATE
	glibtop_init_proc_state_s,
#endif
#if !GLIBTOP_SUID_PROC_UID
	glibtop_init_proc_uid_s,
#endif
#if !GLIBTOP_SUID_PROC_MEM
	glibtop_init_proc_mem_s,
#endif
#if !GLIBTOP_SUID_PROC_TIME
	glibtop_init_proc_time_s,
#endif
#if !GLIBTOP_SUID_PROC_SIGNAL
	glibtop_init_proc_signal_s,
#endif
#if !GLIBTOP_SUID_PROC_KERNEL
	glibtop_init_proc_kernel_s,
#endif
#if !GLIBTOP_SUID_PROC_SEGMENT
	glibtop_init_proc_segment_s,
#endif
#if !GLIBTOP_SUID_PROC_ARGS
	glibtop_init_proc_args_s,
#endif
#if !GLIBTOP_SUID_PROC_MAP
	glibtop_init_proc_map_s,
#endif
#if !GLIBTOP_SUID_INTERFACE_NAMES
	glibtop_init_interface_names_s,
#endif
#if !GLIBTOP_SUID_NETINFO
	glibtop_init_netinfo_s,
#endif
#if !GLIBTOP_SUID_NETLOAD
	glibtop_init_netload_s,
#endif
#if !GLIBTOP_SUID_PPP
	glibtop_init_ppp_s,
#endif
	NULL
};

==> libgtop-1.1.5.tar.gz: libgtop-1.1.5/backends/sysdeps/marshal.c <==
/* marshal.c */
/* This is a generated file.  Please modify `marshal.pl' */

#include <glibtop.h>
#include <glibtop/open.h>
#include <glibtop/xmalloc.h>

#include <glibtop/sysdeps.h>
#include <glibtop/union.h>

#include <glibtop/backend.h>

#include <glibtop-backend-private.h>

#if (!GLIBTOP_SUID_CPU)

static int
_glibtop_get_cpu_c (glibtop *server, glibtop_backend *backend, glibtop_cpu *buf)
{
	return glibtop_get_cpu_s (server, buf);

}

#endif /* not GLIBTOP_SUID_CPU */


#if (!GLIBTOP_SUID_MEM)

static int
_glibtop_get_mem_c (glibtop *server, glibtop_backend *backend, glibtop_mem *buf)
{
	return glibtop_get_mem_s (server, buf);

}

#endif /* not GLIBTOP_SUID_MEM */


#if (!GLIBTOP_SUID_SWAP)

static int
_glibtop_get_swap_c (glibtop *server, glibtop_backend *backend, glibtop_swap *buf)
{
	return glibtop_get_swap_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SWAP */


#if (!GLIBTOP_SUID_UPTIME)

static int
_glibtop_get_uptime_c (glibtop *server, glibtop_backend *backend, glibtop_uptime *buf)
{
	return glibtop_get_uptime_s (server, buf);

}

#endif /* not GLIBTOP_SUID_UPTIME */


#if (!GLIBTOP_SUID_LOADAVG)

static int
_glibtop_get_loadavg_c (glibtop *server, glibtop_backend *backend, glibtop_loadavg *buf)
{
	return glibtop_get_loadavg_s (server, buf);

}

#endif /* not GLIBTOP_SUID_LOADAVG */


#if (!GLIBTOP_SUID_SHM_LIMITS)

static int
_glibtop_get_shm_limits_c (glibtop *server, glibtop_backend *backend, glibtop_shm_limits *buf)
{
	return glibtop_get_shm_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SHM_LIMITS */


#if (!GLIBTOP_SUID_MSG_LIMITS)

static int
_glibtop_get_msg_limits_c (glibtop *server, glibtop_backend *backend, glibtop_msg_limits *buf)
{
	return glibtop_get_msg_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_MSG_LIMITS */


#if (!GLIBTOP_SUID_SEM_LIMITS)

static int
_glibtop_get_sem_limits_c (glibtop *server, glibtop_backend *backend, glibtop_sem_limits *buf)
{
	return glibtop_get_sem_limits_s (server, buf);

}

#endif /* not GLIBTOP_SUID_SEM_LIMITS */


#if (!GLIBTOP_SUID_PROCLIST)

static unsigned *
_glibtop_get_proclist_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                         int64_t which, int64_t arg)
{
	return glibtop_get_proclist_s (server, array, which, arg);

}

#endif /* not GLIBTOP_SUID_PROCLIST */


#if (!GLIBTOP_SUID_PROC_STATE)

static int
_glibtop_get_proc_state_c (glibtop *server, glibtop_backend *backend, glibtop_proc_state *buf,
                           pid_t pid)
{
	return glibtop_get_proc_state_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_STATE */


#if (!GLIBTOP_SUID_PROC_UID)

static int
_glibtop_get_proc_uid_c (glibtop *server, glibtop_backend *backend, glibtop_proc_uid *buf,
                         pid_t pid)
{
	return glibtop_get_proc_uid_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_UID */


#if (!GLIBTOP_SUID_PROC_MEM)

static int
_glibtop_get_proc_mem_c (glibtop *server, glibtop_backend *backend, glibtop_proc_mem *buf,
                         pid_t pid)
{
	return glibtop_get_proc_mem_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_MEM */


#if (!GLIBTOP_SUID_PROC_TIME)

static int
_glibtop_get_proc_time_c (glibtop *server, glibtop_backend *backend, glibtop_proc_time *buf,
                          pid_t pid)
{
	return glibtop_get_proc_time_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_TIME */


#if (!GLIBTOP_SUID_PROC_SIGNAL)

static int
_glibtop_get_proc_signal_c (glibtop *server, glibtop_backend *backend, glibtop_proc_signal *buf,
                            pid_t pid)
{
	return glibtop_get_proc_signal_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_SIGNAL */


#if (!GLIBTOP_SUID_PROC_KERNEL)

static int
_glibtop_get_proc_kernel_c (glibtop *server, glibtop_backend *backend, glibtop_proc_kernel *buf,
                            pid_t pid)
{
	return glibtop_get_proc_kernel_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_KERNEL */


#if (!GLIBTOP_SUID_PROC_SEGMENT)

static int
_glibtop_get_proc_segment_c (glibtop *server, glibtop_backend *backend, glibtop_proc_segment *buf,
                             pid_t pid)
{
	return glibtop_get_proc_segment_s (server, buf, pid);

}

#endif /* not GLIBTOP_SUID_PROC_SEGMENT */


#if (!GLIBTOP_SUID_PROC_ARGS)

static char **
_glibtop_get_proc_args_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                          pid_t pid)
{
	return glibtop_get_proc_args_s (server, array, pid);

}

#endif /* not GLIBTOP_SUID_PROC_ARGS */


#if (!GLIBTOP_SUID_PROC_MAP)

static glibtop_map_entry *
_glibtop_get_proc_map_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                         pid_t pid)
{
	return glibtop_get_proc_map_s (server, array, pid);

}

#endif /* not GLIBTOP_SUID_PROC_MAP */


#if (!GLIBTOP_SUID_INTERFACE_NAMES)

static glibtop_interface *
_glibtop_get_interface_names_c (glibtop *server, glibtop_backend *backend, glibtop_array *array,
                                u_int64_t interface, u_int64_t number, u_int64_t instance, u_int64_t strategy)
{
	return glibtop_get_interface_names_s (server, array, interface, number, instance, strategy);

}

#endif /* not GLIBTOP_SUID_INTERFACE_NAMES */


#if (!GLIBTOP_SUID_NETINFO)

static glibtop_ifaddr *
_glibtop_get_netinfo_c (glibtop *server, glibtop_backend *backend, glibtop_array *array, glibtop_netinfo *buf,
                        const char * interface, u_int64_t transport)
{
	return glibtop_get_netinfo_s (server, array, buf, interface, transport);

}

#endif /* not GLIBTOP_SUID_NETINFO */


#if (!GLIBTOP_SUID_NETLOAD)

static int
_glibtop_get_netload_c (glibtop *server, glibtop_backend *backend, glibtop_netload *buf,
                        const char * interface, unsigned transport, unsigned protocol)
{
	return glibtop_get_netload_s (server, buf, interface, transport, protocol);

}

#endif /* not GLIBTOP_SUID_NETLOAD */


#if (!GLIBTOP_SUID_PPP)

static int
_glibtop_get_ppp_c (glibtop *server, glibtop_backend *backend, glibtop_ppp *buf,
                    unsigned short device, unsigned short use_isdn)
{
	return glibtop_get_ppp_s (server, buf, device, use_isdn);

}

#endif /* not GLIBTOP_SUID_PPP */


glibtop_call_vector glibtop_backend_sysdeps_call_vector = {
#if GLIBTOP_SUID_CPU
	NULL,
#else
	_glibtop_get_cpu_c,
#endif
#if GLIBTOP_SUID_MEM
	NULL,
#else
	_glibtop_get_mem_c,
#endif
#if GLIBTOP_SUID_SWAP
	NULL,
#else
	_glibtop_get_swap_c,
#endif
#if GLIBTOP_SUID_UPTIME
	NULL,
#else
	_glibtop_get_uptime_c,
#endif
#if GLIBTOP_SUID_LOADAVG
	NULL,
#else
	_glibtop_get_loadavg_c,
#endif
#if GLIBTOP_SUID_SHM_LIMITS
	NULL,
#else
	_glibtop_get_shm_limits_c,
#endif
#if GLIBTOP_SUID_MSG_LIMITS
	NULL,
#else
	_glibtop_get_msg_limits_c,
#endif
#if GLIBTOP_SUID_SEM_LIMITS
	NULL,
#else
	_glibtop_get_sem_limits_c,
#endif
#if GLIBTOP_SUID_PROCLIST
	NULL,
#else
	_glibtop_get_proclist_c,
#endif
#if GLIBTOP_SUID_PROC_STATE
	NULL,
#else
	_glibtop_get_proc_state_c,
#endif
#if GLIBTOP_SUID_PROC_UID
	NULL,
#else
	_glibtop_get_proc_uid_c,
#endif
#if GLIBTOP_SUID_PROC_MEM
	NULL,
#else
	_glibtop_get_proc_mem_c,
#endif
#if GLIBTOP_SUID_PROC_TIME
	NULL,
#else
	_glibtop_get_proc_time_c,
#endif
#if GLIBTOP_SUID_PROC_SIGNAL
	NULL,
#else
	_glibtop_get_proc_signal_c,
#endif
#if GLIBTOP_SUID_PROC_KERNEL
	NULL,
#else
	_glibtop_get_proc_kernel_c,
#endif
#if GLIBTOP_SUID_PROC_SEGMENT
	NULL,
#else
	_glibtop_get_proc_segment_c,
#endif
#if GLIBTOP_SUID_PROC_ARGS
	NULL,
#else
	_glibtop_get_proc_args_c,
#endif
#if GLIBTOP_SUID_PROC_MAP
	NULL,
#else
	_glibtop_get_proc_map_c,
#endif
	NULL,
	NULL,
#if GLIBTOP_SUID_INTERFACE_NAMES
	NULL,
#else
	_glibtop_get_interface_names_c,
#endif
#if GLIBTOP_SUID_NETINFO
	NULL,
#else
	_glibtop_get_netinfo_c,
#endif
#if GLIBTOP_SUID_NETLOAD
	NULL,
#else
	_glibtop_get_netload_c,
#endif
#if GLIBTOP_SUID_PPP
	NULL,
#else
	_glibtop_get_ppp_c,
#endif
};

glibtop_init_func_t _glibtop_init_hook_s [] = {
#if !GLIBTOP_SUID_CPU
	glibtop_init_cpu_s,
#endif
#if !GLIBTOP_SUID_MEM
	glibtop_init_mem_s,
#endif
#if !GLIBTOP_SUID_SWAP
	glibtop_init_swap_s,
#endif
#if !GLIBTOP_SUID_UPTIME
	glibtop_init_uptime_s,
#endif
#if !GLIBTOP_SUID_LOADAVG
	glibtop_init_loadavg_s,
#endif
#if !GLIBTOP_SUID_SHM_LIMITS
	glibtop_init_shm_limits_s,
#endif
#if !GLIBTOP_SUID_MSG_LIMITS
	glibtop_init_msg_limits_s,
#endif
#if !GLIBTOP_SUID_SEM_LIMITS
	glibtop_init_sem_limits_s,
#endif
#if !GLIBTOP_SUID_PROCLIST
	glibtop_init_proclist_s,
#endif
#if !GLIBTOP_SUID_PROC_STATE
	glibtop_init_proc_state_s,
#endif
#if !GLIBTOP_SUID_PROC_UID
	glibtop_init_proc_uid_s,
#endif
#if !GLIBTOP_SUID_PROC_MEM
	glibtop_init_proc_mem_s,
#endif
#if !GLIBTOP_SUID_PROC_TIME
	glibtop_init_proc_time_s,
#endif
#if !GLIBTOP_SUID_PROC_SIGNAL
	glibtop_init_proc_signal_s,
#endif
#if !GLIBTOP_SUID_PROC_KERNEL
	glibtop_init_proc_kernel_s,
#endif
#if !GLIBTOP_SUID_PROC_SEGMENT
	glibtop_init_proc_segment_s,
#endif
#if !GLIBTOP_SUID_PROC_ARGS
	glibtop_init_proc_args_s,
#endif
#if !GLIBTOP_SUID_PROC_MAP
	glibtop_init_proc_map_s,
#endif
#if !GLIBTOP_SUID_INTERFACE_NAMES
	glibtop_init_interface_names_s,
#endif
#if !GLIBTOP_SUID_NETINFO
	glibtop_init_netinfo_s,
#endif
#if !GLIBTOP_SUID_NETLOAD
	glibtop_init_netload_s,
#endif
#if !GLIBTOP_SUID_PPP
	glibtop_init_ppp_s,
#endif
	NULL
};
